@@ -5,7 +5,6 @@ Base Resolver Class
 from typing import List, Optional
 
 from mindflow.db.objects.document import DocumentReference
-from mindflow.db.static_definition import ObjectConfig
 
 
 class BaseResolver:
@@ -14,7 +13,7 @@ class BaseResolver:
     """
 
     @staticmethod
-    def read_document(self, document_path: str) -> Optional[str]:
+    def read_document(document_path: str) -> Optional[str]:
         """
         Read a document.
         """
@@ -24,8 +23,10 @@ class BaseResolver:
         """
         Checks if a string is a valid document path for this resolver.
         """
+        return False
 
-    def resolve(self, document_path: str, document_config: ObjectConfig) -> List[DocumentReference]:
+    def resolve(self, document_path: str) -> List[DocumentReference]:
         """
         Resolve a document path to text.
         """
+        return []
