@@ -4,7 +4,6 @@ File/Directory Resolver
 import os
 
 from typing import List, Optional, Union
-from mindflow.db.static_definition import ObjectConfig
 
 from mindflow.resolving.resolvers.base_resolver import BaseResolver
 from mindflow.db.objects.document import Document, DocumentReference
@@ -18,17 +17,6 @@ class FileResolver(BaseResolver):
     Resolver for file or directory paths to text.
     """
 
-    @staticmethod
-    def read_document(document_path: str) -> Optional[str]:
-        """
-        Read a document.
-        """
-        try:
-            with open(document_path, "r", encoding="utf-8") as file:
-                return file.read()
-        except UnicodeDecodeError:
-            return None
-
     @staticmethod
     def should_resolve(document_path: Union[str, os.PathLike]) -> bool:
         """
@@ -36,18 +24,21 @@ class FileResolver(BaseResolver):
         """
         return os.path.isfile(document_path) or os.path.isdir(document_path)
 
-    def resolve(self, document_path: str, document_config: ObjectConfig) -> List[DocumentReference]:
+    def resolve(self, document_path: str) -> List[DocumentReference]:
         """
         Extract text from files.
         """
         document_references: List[DocumentReference] = []
         for path in extract_files(document_path):
-            document_text = self.read_document(path)
-            if not document_text:
-                continue
-            document_references.append(
-                Document.create_document_reference(
-                    path, document_text, DocumentType.FILE.value, document_config
-                )
-            )
+            document_reference: Optional[DocumentReference] = None
+            document = Document.load(path)
+
+            if document:
+                document_reference = document.to_document_reference()
+            else:
+                document_reference = DocumentReference.from_path(path, DocumentType.FILE)
+            
+            if document_reference:
+                document_references.append(document_reference)
+    
         return document_references
